when_to_renew

Function when_to_renew 

pub fn when_to_renew(
    not_after: i64,
    ari: Option<(i64, i64)>,
    renew_before_secs: i64,
) -> i64
Unix time at which the certificate should be renewed: renew_before ahead of expiry, or the start of the CA’s ARI window if that comes first.