pub struct AcmeMetrics {
pub not_after: IntGaugeVec,
pub state: IntGaugeVec,
pub renewals: IntCounterVec,
pub last_attempt: IntGaugeVec,
}Fields
not_after: IntGaugeVecfeatherbit_acme_cert_not_after_timestamp_seconds{cert_id} (0 for placeholders).
state: IntGaugeVecfeatherbit_acme_cert_state{cert_id,state} — 1 for the current state, 0 otherwise.
renewals: IntCounterVecfeatherbit_acme_renewals_total{cert_id,result="success"|"failure"}.
last_attempt: IntGaugeVecfeatherbit_acme_last_renewal_attempt_timestamp_seconds{cert_id}.
Implementations
Sourceimpl AcmeMetrics
impl AcmeMetrics
Sourcepub fn register(registry: &Registry) -> Result<Arc<Self>, Error>
pub fn register(registry: &Registry) -> Result<Arc<Self>, Error>
Creates the collectors and registers them on registry.
Returns an error if any collector is already registered on this registry
(programming error; each registry must be used for at most one register call).
pub fn observe(&self, cert_id: &str, state: CertState, not_after: i64)
pub fn attempt(&self, cert_id: &str, success: bool, at: i64)