async fn get_policy(
__arg0: State<Arc<SharedState>>,
__arg1: Path<String>,
) -> impl IntoResponseExpand description
GET /api/policies/{name} — returns the named policy as JSON.
Errors: 404 Not Found if no policy with that name exists.
async fn get_policy(
__arg0: State<Arc<SharedState>>,
__arg1: Path<String>,
) -> impl IntoResponseGET /api/policies/{name} — returns the named policy as JSON.
Errors: 404 Not Found if no policy with that name exists.