async fn get_route(
__arg0: State<Arc<SharedState>>,
__arg1: Path<String>,
) -> impl IntoResponseExpand description
GET /api/routes/{name} — returns the named route as JSON.
Errors: 404 Not Found if no route with that name exists.
async fn get_route(
__arg0: State<Arc<SharedState>>,
__arg1: Path<String>,
) -> impl IntoResponseGET /api/routes/{name} — returns the named route as JSON.
Errors: 404 Not Found if no route with that name exists.