capture_body

Function capture_body 

fn capture_body(
    body: &Bytes,
    prev: Option<&Bytes>,
    opts: &CaptureOptions,
) -> BodyCapture
Records the body length always, and the text only when capture is on and the bytes differ from the previous step.