pub struct PreviousBodies {
pub request: Option<Bytes>,
pub response: Option<Bytes>,
}Expand description
The bodies seen at the previous step, used to avoid storing an unchanged
body once per node. Cloning Bytes is a refcount bump, not a copy.
Fields
request: Option<Bytes>response: Option<Bytes>Trait Implementations
Sourceimpl Clone for PreviousBodies
impl Clone for PreviousBodies
Sourcefn clone(&self) -> PreviousBodies
fn clone(&self) -> PreviousBodies
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreviousBodies
impl Debug for PreviousBodies
Sourceimpl Default for PreviousBodies
impl Default for PreviousBodies
Sourcefn default() -> PreviousBodies
fn default() -> PreviousBodies
Returns the “default value” for a type. Read more