parse_sampler

Function parse_sampler 

fn parse_sampler(config: &HashMap<String, Value>) -> Result<Sampler, String>
Parses the sampler config object into a Sampler, failing fast on an unknown strategy name or a malformed fraction.