fn compile_schema( config: &HashMap<String, Value>, key: &str, ) -> Result<Option<Validator>, String>
Compiles an optional schema key into a validator, failing fast with the key name on malformed schemas.