pub struct PluginOutput {
pub context: Context,
pub port: Option<&'static str>,
}Expand description
The result of a successful plugin execution.
Fields
context: ContextThe (possibly mutated) context, passed on to the next node in the graph.
port: Option<&'static str>Declared output port this result leaves on. None = success.
Must name a port of kind outcome in the node type’s PortSpec.
Implementations