pub fn resolve(
config: &HashMap<String, Value>,
resources: &Arc<PluginResources>,
node_type: &str,
) -> Result<StoreHandle, String>Expand description
Resolves the store config key to a handle, at construction time.
pub fn resolve(
config: &HashMap<String, Value>,
resources: &Arc<PluginResources>,
node_type: &str,
) -> Result<StoreHandle, String>Resolves the store config key to a handle, at construction time.