fn capture_body(
body: &Bytes,
prev: Option<&Bytes>,
opts: &CaptureOptions,
) -> BodyCaptureExpand description
Records the body length always, and the text only when capture is on and the bytes differ from the previous step.
fn capture_body(
body: &Bytes,
prev: Option<&Bytes>,
opts: &CaptureOptions,
) -> BodyCaptureRecords the body length always, and the text only when capture is on and the bytes differ from the previous step.