pub(crate) async fn build_etcd_source(
system: &SystemConfig,
seed_path: &Path,
) -> Result<(Arc<dyn ConfigStore>, GatewayConfig, Option<PathBuf>), String>Expand description
Builds the etcd config store and the initial gateway config (seeding etcd from the local file when the prefix is empty).